use defmt::{info, unwrap};
use nrf_softdevice::ble::advertisement_builder::{
    Flag, LegacyAdvertisementBuilder, LegacyAdvertisementPayload, ServiceList, ServiceUuid16,
};
use nrf_softdevice::ble::peripheral::ConnectableAdvertisement;
use nrf_softdevice::ble::{peripheral, Connection};
use nrf_softdevice::Softdevice;

static SCAN_DATA: LegacyAdvertisementPayload = LegacyAdvertisementBuilder::new()
    .services_128(
        ServiceList::Complete,
        &[0x9e7312e0_2354_11eb_9f10_fbc30a62cf38_u128.to_le_bytes()],
    )
    .build();

pub async fn run(sd: &Softdevice, device_name: &str) -> Connection {
    let config = peripheral::Config::default();

    let adv_data = LegacyAdvertisementBuilder::new()
        .flags(&[Flag::GeneralDiscovery, Flag::LE_Only])
        .services_16(ServiceList::Complete, &[ServiceUuid16::BATTERY])
        .full_name(device_name)
        .build();

    let adv = ConnectableAdvertisement::ScannableUndirected {
        adv_data: &adv_data,
        scan_data: &SCAN_DATA,
    };
    info!("advertising started");
    unwrap!(peripheral::advertise_connectable(sd, adv, &config).await)
}
